@@ -1,6 +1,7 @@
 from django.contrib import messages
 from django.contrib.auth.mixins import LoginRequiredMixin, PermissionRequiredMixin
 from django.http import HttpResponse
+from django.shortcuts import redirect
 from django.utils.html import format_html
 from django.utils.safestring import mark_safe
 from django.views import View
@@ -16,6 +17,16 @@ class HomeView(View):
         return HttpResponse(self.html)
 
 
+class LoginView(View):
+    html = "<html><head><title>Login</title></head><body>Login</body></html>"
+
+    def get(self, *args, **kwargs):
+        return HttpResponse(self.html)
+
+    def post(self, *args, **kwargs):
+        return HttpResponse(self.html)
+
+
 class LoginRequiredView(LoginRequiredMixin, HomeView):
     pass
 
@@ -42,3 +53,8 @@ class MessageView(View):
         if message:
             messages.add_message(self.request, messages.INFO, message)
         return HttpResponse(mark_safe("<html><head><title>Message</title></head><body>Message</body></html>"))
+
+
+def redirect_root(request):
+    """Redirects to root url."""
+    return redirect("/")
